<?php

$block_name = _("Story");

/**
 * This class extends Horde_Block:: to provide the api to embed news
 * in other Horde applications.
 *
 * $Horde: jonah/lib/Block/story.php,v 1.1 2006/09/10 17:41:04 chuck Exp $
 *
 * Copyright 2002-2006 Roel Gloudemans <roel@gloudemans.info>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 *
 * @author  Roel Gloudemans <roel@gloudemans.info>
 * @package Horde_Block
 */
class Horde_Block_Jonah_story extends Horde_Block {

    var $_app = 'jonah';

    /**
     */
    function Horde_Block_Jonah_story($params = array())
    {
        parent::Horde_Block($params);

        @define('JONAH_BASE', dirname(__FILE__) . '/../..');
        require_once JONAH_BASE . '/lib/Jonah.php';
        require_once JONAH_BASE . '/lib/News.php';
    }

    /**
     */
    function _params()
    {
        $news = Jonah_News::factory();
        $channels = $news->getChannels(JONAH_INTERNAL_CHANNEL);
        $channel_choices = array();
        foreach ($channels as $channel) {
            $channel_choices[$channel['channel_id']] = $channel['channel_name'];
        }
        natcasesort($channel_choices);

        return array('source' => array(
                         'name' => _("Feed"),
                         'type' => 'enum',
                         'values' => $channel_choices),
                     'story' => array(
                         'name' => _("Story"),
                         'type' => 'int'));
    }

    /**
     */
    function _title()
    {
        if (empty($this->_params['source']) || empty($this->_params['story'])) {
            return _("Story");
        }

        $story = $this->_fetch();
        return is_a($story, 'PEAR_Error') ?
            $story->getMessage() :
            '<span class="storyDate">' . htmlspecialchars($story['story_updated_date']) . '</span> ' . htmlspecialchars($story['story_title']);
    }

    /**
     */
    function _content()
    {
        if (empty($this->_params['source']) || empty($this->_params['story'])) {
            return _("No story is selected.");
        }

        $story = $this->_fetch();
        if (is_a($story, 'PEAR_Error')) {
            return sprintf(_("Error fetching story: %s"), $story->getMessage());
        }

        if (empty($story['story_body_type']) || $story['story_body_type'] == 'text') {
            require_once 'Horde/Text/Filter.php';
            $story['story_body'] = Text_Filter::filter($story['story_body'], 'text2html', array('parselevel' => TEXT_HTML_MICRO, 'class' => null));
        }

        return '<p class="storySubtitle">' . htmlspecialchars($story['story_desc']) .
            '</p><div class="storyBody">' . $story['story_body'] . '</div>';
    }

    /**
     * Get the story the block is configured for.
     */
    function _fetch()
    {
        $news = Jonah_News::factory();
        return $news->getStory($this->_params['source'],
                               $this->_params['story']);
    }

}
