<?php
/**
 * Jonah external API interface.
 *
 * $Horde: jonah/lib/api.php,v 1.62 2007/03/12 05:02:40 mrubinsk Exp $
 *
 * This file defines Jonah's external API interface. Other
 * applications can interact with Jonah through this API.
 *
 * @package Jonah
 */

$_services['perms'] = array(
    'args' => array(),
    'type' => '{urn:horde}stringArray'
);

$_services['stories'] = array(
    'args' => array('channel' => 'int',
                    'max_stories' => 'int',
                    'start_at' => 'int',
                    'order' => 'int'),
    'type' => '{urn:horde}stringArray'
);

$_services['story'] = array(
    'args' => array('channel' => 'int',
                    'story' => 'int',
                    'read' => 'bool'),
    'type' => '{urn:horde}stringArray'
);

$_services['commentCallback'] = array(
    'args' => array('story_id' => 'string'),
    'type' => 'string'
);

$_services['hasComments'] = array(
    'args' => array(),
    'type' => 'boolean'
);

function _jonah_perms()
{
    require_once dirname(__FILE__) . '/base.php';
    require_once JONAH_BASE . '/lib/News.php';

    $news = Jonah_News::factory();
    $channels = $news->getChannels(JONAH_INTERNAL_CHANNEL);

    /* Loop through internal channels and add their ids to the
     * perms. */
    $perms = array();
    foreach ($channels as $channel) {
        $perms['tree']['jonah']['news']['internal_channels'][$channel['channel_id']] = false;
    }

    /* Human names. */
    $perms['title']['jonah:news'] = _("News");
    $perms['title']['jonah:news:internal_channels'] = _("Internal Channels");

    /* Loop through internal channels and add them to the perms
     * titles. */
    foreach ($channels as $channel) {
        $perms['title']['jonah:news:internal_channels:' . $channel['channel_id']] = $channel['channel_name'];
    }

    $channels = $news->getChannels(JONAH_EXTERNAL_CHANNEL);

    /* Loop through external channels and add their ids to the
     * perms. */
    foreach ($channels as $channel) {
        $perms['tree']['jonah']['news']['external_channels'][$channel['channel_id']] = false;
    }

    /* Human names. */
    $perms['title']['jonah:news'] = _("News");
    $perms['title']['jonah:news:external_channels'] = _("External Channels");

    /* Loop through external channels and add them to the perms
     * titles. */
    foreach ($channels as $channel) {
        $perms['title']['jonah:news:external_channels:' . $channel['channel_id']] = $channel['channel_name'];
    }

    $perms['tree']['jonah']['admin'] = array();
    $perms['title']['jonah:admin'] = _("Administrator");

    return $perms;
}

/**
 * Return the requested stories
 *
 * @param int $channel_id   The channel to get the stories from.
 * @param int $max_stories  The maximum number of stories to get.
 * @param int $start_at     The story number to start retrieving.
 * @param int $order        How to order the results.
 *
 * @return An array of story information | PEAR_Error
 */
function _jonah_stories($channel_id, $max_stories = 10, $start_at = 0,
                        $order = 0)
{
    require_once dirname(__FILE__) . '/base.php';
    require_once JONAH_BASE . '/lib/News.php';
    $news = Jonah_News::factory();
    $stories = $news->getStories($channel_id, $max_stories, $start_at, false,
                                 time(), false, $order);
    return $stories;
}

function _jonah_story($channel_id, $story_id, $read = true)
{
    require_once dirname(__FILE__) . '/base.php';
    require_once JONAH_BASE . '/lib/News.php';

    $news = Jonah_News::factory();
    return $news->getStory($channel_id, $story_id, $read);
}

function _jonah_commentCallback($story_id)
{
    if (!$GLOBALS['conf']['comments']['allow']) {
        return false;
    }

    require_once dirname(__FILE__) . '/base.php';
    require_once JONAH_BASE . '/lib/News.php';

    $news = Jonah_News::factory();
    $story = $news->getStory(null, $story_id);
    if (is_a($story, 'PEAR_Error')) {
        return false;
    }

    return $story['story_title'];
}

function _jonah_hasComments()
{
    return $GLOBALS['conf']['comments']['allow'];
}
